gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r28520 - gnunet/src/mesh


From: gnunet
Subject: [GNUnet-SVN] r28520 - gnunet/src/mesh
Date: Mon, 12 Aug 2013 14:47:21 +0200

Author: bartpolot
Date: 2013-08-12 14:47:21 +0200 (Mon, 12 Aug 2013)
New Revision: 28520

Modified:
   gnunet/src/mesh/Makefile.am
   gnunet/src/mesh/test_mesh.conf
   gnunet/src/mesh/test_mesh_local.c
Log:
- use new mesh for test_mesh_local

Modified: gnunet/src/mesh/Makefile.am
===================================================================
--- gnunet/src/mesh/Makefile.am 2013-08-12 11:53:23 UTC (rev 28519)
+++ gnunet/src/mesh/Makefile.am 2013-08-12 12:47:21 UTC (rev 28520)
@@ -132,9 +132,9 @@
 libgnunetmeshtest_a_LIBADD = \
  $(top_builddir)/src/util/libgnunetutil.la \
  $(top_builddir)/src/testbed/libgnunettestbed.la \
- $(top_builddir)/src/mesh/libgnunetmesh.la
+ $(top_builddir)/src/mesh/libgnunetmeshenc.la
 libgnunetmeshtest_a_DEPENDENCIES = \
-  libgnunetmesh.la
+  libgnunetmeshenc.la
 
 if HAVE_TESTING
 check_PROGRAMS = \
@@ -155,11 +155,11 @@
   $(top_builddir)/src/util/libgnunetutil.la \
   $(top_builddir)/src/testing/libgnunettesting.la \
   $(top_builddir)/src/mesh/libgnunetmeshtest.a \
-  $(top_builddir)/src/mesh/libgnunetmesh.la \
+  $(top_builddir)/src/mesh/libgnunetmeshenc.la \
   $(top_builddir)/src/testbed/libgnunettestbed.la
 
 dep_mesh_test_lib = \
-  libgnunetmesh.la \
+  libgnunetmeshenc.la \
   libgnunetmeshtest.a
 
 test_mesh_single_SOURCES = \

Modified: gnunet/src/mesh/test_mesh.conf
===================================================================
--- gnunet/src/mesh/test_mesh.conf      2013-08-12 11:53:23 UTC (rev 28519)
+++ gnunet/src/mesh/test_mesh.conf      2013-08-12 12:47:21 UTC (rev 28520)
@@ -2,7 +2,7 @@
 SERVICEHOME = /tmp/test-mesh/
 
 [mesh]
-#BINARY = gnunet-service-mesh
+BINARY = gnunet-service-mesh-enc
 AUTOSTART = NO
 ACCEPT_FROM = 127.0.0.1;
 HOSTNAME = localhost

Modified: gnunet/src/mesh/test_mesh_local.c
===================================================================
--- gnunet/src/mesh/test_mesh_local.c   2013-08-12 11:53:23 UTC (rev 28519)
+++ gnunet/src/mesh/test_mesh_local.c   2013-08-12 12:47:21 UTC (rev 28520)
@@ -28,7 +28,7 @@
 #include "gnunet_util_lib.h"
 #include "gnunet_dht_service.h"
 #include "gnunet_testing_lib.h"
-#include "gnunet_mesh_service.h"
+#include "gnunet_mesh_service_enc.h"
 
 struct GNUNET_TESTING_Peer *me;
 
@@ -36,7 +36,7 @@
 
 static struct GNUNET_MESH_Handle *mesh_peer_2;
 
-static struct GNUNET_MESH_Tunnel *t;
+static struct GNUNET_MESH_Channel *ch;
 
 static int result = GNUNET_OK;
 
@@ -56,9 +56,9 @@
   {
     GNUNET_SCHEDULER_cancel (abort_task);
   }
-  if (NULL != t)
+  if (NULL != ch)
   {
-    GNUNET_MESH_tunnel_destroy (t);
+    GNUNET_MESH_channel_destroy (ch);
   }
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Disconnect client 1\n");
   if (NULL != mesh_peer_1)
@@ -95,15 +95,16 @@
  * Function is called whenever a message is received.
  *
  * @param cls closure (set from GNUNET_MESH_connect)
  * @param tunnel connection to the other end
  * @param tunnel_ctx place to store local state associated with the tunnel
  * @param message the actual message
  * 
  * @return GNUNET_OK to keep the connection open,
  *         GNUNET_SYSERR to close it (signal serious error)
  */
 static int
-data_callback (void *cls, struct GNUNET_MESH_Tunnel *tunnel, void **tunnel_ctx,
+data_callback (void *cls, struct GNUNET_MESH_Channel *channel,
+               void **channel_ctx,
                const struct GNUNET_MessageHeader *message)
 {
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "Data callback! Shutting down.\n");
@@ -112,23 +113,24 @@
   shutdown_task =
     GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_SECONDS, &do_shutdown,
                                   NULL);
-  GNUNET_MESH_receive_done (tunnel);
+  GNUNET_MESH_receive_done (channel);
   return GNUNET_OK;
 }
 
 
 /**
  * Method called whenever another peer has added us to a tunnel
  * the other peer initiated.
  *
  * @param cls closure
  * @param tunnel new handle to the tunnel
  * @param initiator peer that started the tunnel
  * @param port port number
- * @return initial tunnel context for the tunnel (can be NULL -- that's not an 
error)
+ * @return initial channel context for the channel
+ *         (can be NULL -- that's not an error)
  */
 static void *
-inbound_tunnel (void *cls, struct GNUNET_MESH_Tunnel *tunnel,
+inbound_tunnel (void *cls, struct GNUNET_MESH_Channel *channel,
                 const struct GNUNET_PeerIdentity *initiator,
                 uint32_t port)
 {
@@ -148,22 +150,22 @@
 
 
 /**
  * Function called whenever an inbound tunnel is destroyed.  Should clean up
  * any associated state.
  *
  * @param cls closure (set from GNUNET_MESH_connect)
  * @param tunnel connection to the other end (henceforth invalid)
  * @param tunnel_ctx place where local state associated
  *                   with the tunnel is stored
  */
 static void
-inbound_end (void *cls, const struct GNUNET_MESH_Tunnel *tunnel,
-             void *tunnel_ctx)
+inbound_end (void *cls, const struct GNUNET_MESH_Channel *channel,
+             void *channel_ctx)
 {
   long id = (long) cls;
 
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-              "incoming tunnel closed at peer %ld\n",
+              "incoming channel closed at peer %ld\n",
               id);
 }
 
@@ -225,8 +227,9 @@
 
   GNUNET_TESTING_peer_get_identity (me, &id);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, "CONNECT BY PORT\n");
-  t = GNUNET_MESH_tunnel_create (mesh_peer_1, NULL, &id, 1, GNUNET_YES, 
GNUNET_NO);
-  GNUNET_MESH_notify_transmit_ready (t, GNUNET_NO,
+  ch = GNUNET_MESH_channel_create (mesh_peer_1, NULL, &id, 1,
+                                  GNUNET_YES, GNUNET_NO);
+  GNUNET_MESH_notify_transmit_ready (ch, GNUNET_NO,
                                      GNUNET_TIME_UNIT_FOREVER_REL,
                                      sizeof (struct GNUNET_MessageHeader),
                                      &do_send, NULL);
@@ -95,15 +95,16 @@
  *
  * @param cls closure (set from GNUNET_MESH_connect)
- * @param tunnel connection to the other end
- * @param tunnel_ctx place to store local state associated with the tunnel
+ * @param channel connection to the other end
+ * @param channel_ctx place to store local state associated with the channel
  * @param message the actual message
  * 
@@ -112,23 +113,24 @@
 
 /**
- * Method called whenever another peer has added us to a tunnel
+ * Method called whenever another peer has added us to a channel
  * the other peer initiated.
  *
@@ -112,23 +113,24 @@
  *
  * @param cls closure
- * @param tunnel new handle to the tunnel
- * @param initiator peer that started the tunnel
+ * @param channel new handle to the channel
+ * @param initiator peer that started the channel
  * @param port port number
@@ -148,22 +150,22 @@
 
 /**
- * Function called whenever an inbound tunnel is destroyed.  Should clean up
+ * Function called whenever an inbound channel is destroyed.  Should clean up
  * any associated state.
  *
@@ -148,22 +150,22 @@
  *
  * @param cls closure (set from GNUNET_MESH_connect)
- * @param tunnel connection to the other end (henceforth invalid)
- * @param tunnel_ctx place where local state associated
- *                   with the tunnel is stored
+ * @param channel connection to the other end (henceforth invalid)
+ * @param channel_ctx place where local state associated
+ *                    with the channel is stored
  */
 static void




reply via email to

[Prev in Thread] Current Thread [Next in Thread]